Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Activity ¶
type Activity struct {
// contains filtered or unexported fields
}
Activity is an activity that is used to invoke a REST Operation settings : {method, uri, headers, proxy, skipSSL} input : {pathParams, queryParams, headers, content} outputs : {status, result}
type Input ¶
type Input struct {
PathParams map[string]string `md:"pathParams"` // The query parameters (e.g., 'id' in http://.../pet?id=someValue )
QueryParams map[string]string `md:"queryParams"` // The path parameters (e.g., 'id' in http://.../pet/:id/name )
Headers map[string]string `md:"headers"` // The HTTP header parameters
Content interface{} `md:"content"` // The message content to send. This is only used in POST, PUT, and PATCH
}
type Output ¶
type Settings ¶
type Settings struct {
Method string `md:"method,required,allowed(GET,POST,PUT,PATCH,DELETE)"` // The HTTP method to invoke
Uri string `md:"uri,required"` // The URI of the service to invoke
Headers map[string]string `md:"headers"` // The HTTP header parameters
Proxy string `md:"proxy"` // The address of the proxy server to be use
Timeout int `md:"timeout"` // The request timeout in seconds
SkipSSLVerify bool `md:"skipSSLVerify"` // Skip SSL validation
CertFile string `md:"certFile"` // Path to PEM encoded client certificate
KeyFile string `md:"keyFile"` // Path to PEM encoded client key
CAFile string `md:"CAFile"` // Path to PEM encoded root certificates file
SSLConfig map[string]interface{} `md:"sslConfig"` // SSL Configuration
}
Click to show internal directories.
Click to hide internal directories.